#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (c) 2009-2012 by Steven Sproat
#
# GNU General Public Licence (GPL)
#
# Whyteboard is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 3 of the License, or (at your option) any later
# version.
# Whyteboard is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
# You should have received a copy of the GNU General Public License along with
# Whyteboard; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place, Suite 330, Boston, MA  02111-1307  USA


from lib.BeautifulSoup import BeautifulSoup
from lib.soupselect import select

import re
import urllib

class Translators(object):
    def __init__(self):
        self.translators = {}
    
    def add(self, name, url, language):
        if url not in self.translators:
            self.translators[url] = {'name': name, 'languages': [language]}
        else:
            translator = self.translators[url]
            translator['languages'].append(language)
            
    def list(self):
        for url, translator in self.translators.items():
            languages = ", ".join(translator['languages'])
            print "%s %s (%s)" % (translator['name'], url, languages)
    
    
def language_and_translators(lang):
    site = "https://translations.launchpad.net/whyteboard/trunk/+pots/whyteboard/%s/+details" % lang
    try:
        f = urllib.urlopen(site)
    except IOError:
        print "error connecting to site " + site
        exit()

    html = f.read()
    f.close()
    soup = BeautifulSoup(html)
    
    title = select(soup, "title")[0].renderContents()
    regex = re.search('Details : (.*) \(', title)
    
    language = regex.group(1)    
    translators = select(soup, "#maincontent div.portlet li a.person")
    
    return (language, translators)


#---------------------------------------------------------------


all_translators = Translators()

locales = ["ar", "ca", "cs", "cy", "de", "en_GB", "es", "fr", "gl", 
           "hi", "hr", "it", "ja", "ko", "nl", "oc", "pt", "ru", "sk", 
           "sv", "tr", "zh_TW"]

for locale in locales:
    language, translators = language_and_translators(locale)
    
    for translator in translators:
        all_translators.add(translator.renderContents(), translator['href'], language)
     
all_translators.list()