#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (c) 2009-2011 by Steven Sproat
#
# GNU General Public Licence (GPL)
#
# Whyteboard is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 3 of the License, or (at your option) any later
# version.
# Whyteboard is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
# details.
# You should have received a copy of the GNU General Public License along with
# Whyteboard; if not, write to the Free Software Foundation, Inc., 59 Temple
# Place, Suite 330, Boston, MA  02111-1307  USA


'''
A custom log handler that remembers the last x many logs sent to it
for retrieving log messages (in this case, we want to fetch the logs 
if the prorgram crashes
'''

from collections import deque
from logging import StreamHandler, DEBUG
from time import gmtime, strftime

#----------------------------------------------------------------------

class LogRemembererHandler(StreamHandler):
    '''
    A custom log handler that remembers the last x many logs sent to it
    for retrieving log messages (in this case, we want to fetch the logs 
    if the prorgram crashes
    '''
    _instance = None
    def __new__(cls, *args, **kwargs):
        if not cls._instance:
            cls._instance = super(LogRemembererHandler, cls).__new__(cls, *args, **kwargs)
            cls._instance.logs = deque(maxlen=101)            
        return cls._instance
    
    def emit(self, record):
        self.format(record)
        time = strftime("%d/%m/%Y %H:%M:%S", gmtime(record.created))
        self.logs.append("%s: %s" % (time, record.message))
        
    def get_logs(self):
        return self.logs